@@ -39,6 +39,14 @@ More instance operations:
    info
    set_storage
 
+Manage creating and testing migrations (deployment is automatic):
+
+.. autosummary::
+   :toctree:
+
+   migrate
+
+
 Dev API
 -------
 
@@ -50,11 +58,12 @@ Dev API
    Storage
 """
 
-__version__ = "0.28.0"
+__version__ = "0.28.1"
 import atexit
 from os import name as _os_name
 
 from ._info import info  # noqa
+from ._migrations import migrate
 from ._schema import schema  # noqa
 from ._set import set_storage  # noqa
 from ._settings import settings  # noqa
