@@ -29,20 +29,20 @@ def setup_local_test_sqlite_file(
     return tgt_db
 
 
-def setup_local_test_postgres():
+def setup_local_test_postgres(name: str = "pgtest"):
     process = run(
-        "docker run --name pgtest -e POSTGRES_PASSWORD=pwd"
-        " -e POSTGRES_DB=pgtest -d -p 5432:5432 postgres",  # noqa
+        f"docker run --name {name} -e POSTGRES_PASSWORD=pwd"
+        f" -e POSTGRES_DB={name} -d -p 5432:5432 postgres",  # noqa
         shell=True,
     )
     if process.returncode == 0:
         logger.info(
-            "Created Postgres test instance. It runs in docker container 'pgtest'."
+            f"Created Postgres test instance. It runs in docker container '{name}'."
         )
     else:
         raise RuntimeError("Failed to set up postgres test instance.")
     time.sleep(2)
-    return "postgresql://postgres:pwd@0.0.0.0:5432/pgtest"
+    return f"postgresql://postgres:pwd@0.0.0.0:5432/{name}"
 
 
 def clone_schema(
