@@ -1,7 +1,7 @@
 from ._nox import (  # noqa
     build_docs,
-    install_and_run_pytest,
     login_testuser1,
     run_pre_commit,
+    run_pytest,
     setup_test_instances_from_main_branch,
 )
